@@ -2,6 +2,8 @@ mod methods;
 mod traits;
 
 /// A configurable field follows tri-state logic.
+#[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
+#[derive(Debug, Copy, Clone, PartialEq, Eq, Hash)]
 pub enum Setting<T>
 where
     T: Default,
